@@ -124,23 +124,30 @@ class FeatureType(Enum):
 
 
 class TargetMetric(Enum):
-    RECALL_MACRO = 'recall_macro'
     F1 = 'f1'
     F2 = 'f2'
-    Normalized_Gini = 'Normalized Gini'
-    AUC = 'AUC'
-    Log_Less = 'Log loss'
-    Accuracy = 'Accuracy'
-    MAE = 'MAE'
-    Normalized_MSE = 'Normalized MSE'
-    Normalized_EMSE = 'Normalized RMSE'
-    Normalized_MAE = 'Normalized MAE'
-    Median = 'Median AE'
-    R2 = 'R2'
-    RMSPE = 'RMSPE'
-    RMSLE = 'RMSLE'
-    MAPE = 'MAPE'
-    # 'firefly.enums.TargetMetric.RECALL_MACRO', 'firefly.enums.TargetMetric.F1', 'firefly.enums.TargetMetric.F2', 'Normalized Gini', 'AUC', 'Log loss', 'Accuracy', 'MAE', 'Normalized MSE', 'Normalized RMSE', 'Normalized MAE', 'Median AE', 'R2', 'RMSPE', 'RMSLE', 'MAPE']
+    ACCURACY = 'accuracy'
+    MAE = 'mae'
+    NORMALIZED_MAE = 'normalized_mae'
+    MEDIAN_AE = 'median_ae'
+    MAPE = 'mape'
+    RMSLE = 'rmsle'
+    COST_METRIC = 'cost_metric'
+    MSE = 'mse'
+    RMSE = 'rmse'
+    NORMALIZED_MSE = 'normalized_mse'
+    MAE_DISCRETE = 'mae_discrete'
+    RMSPE = 'rmspe'
+    NORMALIZED_RMSE = 'normalized_rmse'
+    RECALL_MACRO = 'recall_macro'
+    NORMALIZED_GINI = 'normalized_gini'
+    SIGNED_SUM = 'signed_sum'
+    LOG_LOSS = 'log_loss'
+    AUC = 'auc'
+    R2 = 'r2'
+    R1 = 'r1'
+    JACCARD = 'jaccard'
+    NORMALIZED_MUTUAL_INFO = 'normalized_mutual_info'
 
 
 class InterpretabilityLevel(Enum):
