@@ -9,7 +9,7 @@ alongside respected feature roles (target, block-id, etc.).
 from typing import Dict, List
 
 import toolkit_w
-# from fireflyai import utils
+from toolkit_w.internal import utils
 from toolkit_w.internal.api_requestor import APIRequestor
 from toolkit_w.internal.vars_global import ProblemType, FeatureType, Estimator, TargetMetric, SplittingStrategy, Pipeline, \
     InterpretabilityLevel, ValidationStrategy, CVStrategy
@@ -163,8 +163,7 @@ class Dataset(APIResource):
 
         if wait:
             id = response['id']
-            #TODO
-            # utils.wait_for_finite_state(cls.get, id, api_key=api_key)
+            utils.wait_for_finite_state(cls.get, id, api_key=api_key)
             response = cls.get(id, api_key=api_key)
 
         return response
